summaryrefslogtreecommitdiff
path: root/src/xsane-preview.h
diff options
context:
space:
mode:
authorMattia Rizzolo <mattia@mapreri.org>2014-10-03 14:05:39 +0000
committerMattia Rizzolo <mattia@mapreri.org>2014-10-03 14:05:39 +0000
commit41b1173190f702693b0b4fd2654cf2dc28a447f4 (patch)
tree03825cd0624f27ab545f8055bdd50db5d567f950 /src/xsane-preview.h
parent1083fdcdb608210a42e00fc6819a6d5ce5996b2a (diff)
Imported Upstream version 0.995upstream/0.995
Diffstat (limited to 'src/xsane-preview.h')
-rw-r--r--src/xsane-preview.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/xsane-preview.h b/src/xsane-preview.h
index a488ce2..9fada8a 100644
--- a/src/xsane-preview.h
+++ b/src/xsane-preview.h
@@ -43,7 +43,7 @@ enum
MODE_PIPETTE_WHITE,
MODE_PIPETTE_GRAY,
MODE_PIPETTE_BLACK,
- MODE_AUTORAISE_SCANAREA,
+ MODE_AUTORAISE_SCAN_AREA,
MODE_ZOOM_IN
};
@@ -185,9 +185,9 @@ typedef struct
GtkWidget *zoom_in; /* zoom in button */
GtkWidget *zoom_area; /* zoom area button */
GtkWidget *zoom_undo; /* zoom undo button */
- GtkWidget *full_area; /* select full scanarea */
- GtkWidget *autoraise; /* autoraise scanarea */
- GtkWidget *autoselect; /* autoselect scanarea */
+ GtkWidget *full_area; /* select full scan area */
+ GtkWidget *autoraise; /* autoraise scan area */
+ GtkWidget *autoselect; /* autoselect scan area */
GtkWidget *preset_area_option_menu; /* menu for selection of preview area */
GtkWidget *rotation_option_menu; /* menu for selection of rotation */
GtkWidget *ratio_option_menu; /* menu for selection of ratio */